@@ -1,7 +1,7 @@
 # Copyright (c) Microsoft Corporation
 # Licensed under the MIT License.
 
-"""Module for wrapped-flask service."""
+"""Module for rai_core_flask service."""
 
 from .flask_helper import FlaskHelper
 
